(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     48900,       1252]*)
(*NotebookOutlinePosition[     50842,       1314]*)
(*  CellTagsIndexPosition[     50613,       1303]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["isospinxyz", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["isospinxyz[", "MR"],
  StyleBox["c", "TI"],
  StyleBox[", ", "MR"],
  StyleBox["i", "TI"],
  StyleBox["]", "MR"],
  " returns the ",
  StyleBox["x", "IT"],
  ", ",
  StyleBox["y", "IT"],
  ", and ",
  StyleBox["z", "IT"],
  " components of the I=1/2 isospin operator for the level described by the \
operator ",
  StyleBox["c", "TI"],
  ". The phase is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\((\(-1\))\)\^i\)\(.\)\)\)]],
  "\n\[FilledSmallSquare] ",
  StyleBox["isospinx[", "MR"],
  StyleBox["c", "TI"],
  StyleBox[", ", "MR"],
  StyleBox["i", "TI"],
  StyleBox["]", "MR"],
  " returns the ",
  StyleBox["x", "IT"],
  " component of the isospin operator.\n\[FilledSmallSquare] ",
  StyleBox["isospiny[", "MR"],
  StyleBox["c", "TI"],
  StyleBox[", ", "MR"],
  StyleBox["i", "TI"],
  StyleBox["]", "MR"],
  " returns the ",
  StyleBox["y", "IT"],
  " component of the isospin operator.\n\[FilledSmallSquare] ",
  StyleBox["isospinz[", "MR"],
  StyleBox["c", "TI"],
  StyleBox[", ", "MR"],
  StyleBox["i", "TI"],
  StyleBox["]", "MR"],
  " returns the ",
  StyleBox["z", "IT"],
  " component of the isospin operator.\n\[FilledSmallSquare] ",
  StyleBox["isospinplus[", "MR"],
  StyleBox["c", "TI"],
  StyleBox[", ", "MR"],
  StyleBox["i", "TI"],
  StyleBox["]", "MR"],
  " returns the + component of the isospin operator,",
  StyleBox[" ", "Notes"],
  Cell[BoxData[
      \(TraditionalForm\`\(I\_+\) = I\_x\)]],
  "+i ",
  Cell[BoxData[
      \(TraditionalForm\`I\_y\)]],
  ".\n\[FilledSmallSquare] ",
  StyleBox["isospinminus[", "MR"],
  StyleBox["c", "TI"],
  StyleBox[", ", "MR"],
  StyleBox["i", "TI"],
  StyleBox["]", "MR"],
  " returns the - component of the isospin operator,",
  StyleBox[" ", "Notes"],
  Cell[BoxData[
      \(TraditionalForm\`\(I\_-\) = I\_x\)]],
  "-i ",
  Cell[BoxData[
      \(TraditionalForm\`I\_y\)]],
  "."
}], "Usage",
  CellTags->{
  "isospinxyz", "isospinx", "isospiny", "isospinz", "isospinplus", 
    "isospinminus"}],

Cell[TextData[{
  "\[FilledSmallSquare] Operator ",
  StyleBox["c", "TI",
    FontSize->10],
  " must be expressed in the stripped form, i.e. a form which excludes the \
first index (creation/annihilation) and the last index (spin). "
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] The default value of index ",
  StyleBox["i", "IT"],
  " is 0."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["spinxyz",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["nambu",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["manyisospin",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell[TextData[{
  "Load sneg and declare ",
  StyleBox["c", "TI"],
  " to be a fermionic operator"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(snegfermionoperators[c];\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell[TextData[{
  "Check definition, phase index ",
  StyleBox["i", "IT"],
  "=0"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \({I\_x, I\_y, I\_z} = isospinxyz[c[], 0]\), "\[IndentingNewLine]", 
    \(komutator[I\_x, I\_y] \[Equal] I\ I\_z // 
      ExpandAll\), "\[IndentingNewLine]", 
    \(komutator[I\_y, I\_z] \[Equal] I\ I\_x // 
      ExpandAll\), "\[IndentingNewLine]", 
    \(komutator[I\_z, I\_x] \[Equal] I\ I\_y // ExpandAll\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(1\/2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\<\"-\"\>", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}], ")"}]}], ",", 
        RowBox[{\(1\/2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\[ImaginaryI]", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{"\[ImaginaryI]", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}], ")"}]}], ",", 
        RowBox[{\(1\/2\), " ", 
          RowBox[{"(", 
            RowBox[{\(-1\), "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}], ")"}]}]}], "}"}]], "Output",
  CellLabel->"Out[3]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[4]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[5]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  "Check definition, phase index ",
  StyleBox["i", "IT"],
  "=1"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \({I\_x, I\_y, I\_z} = isospinxyz[c[], 1]\), "\[IndentingNewLine]", 
    \(komutator[I\_x, I\_y] \[Equal] I\ I\_z // 
      ExpandAll\), "\[IndentingNewLine]", 
    \(komutator[I\_y, I\_z] \[Equal] I\ I\_x // 
      ExpandAll\), "\[IndentingNewLine]", 
    \(komutator[I\_z, I\_x] \[Equal] I\ I\_y // ExpandAll\)}], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(1\/2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "-", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}], ")"}]}], ",", 
        RowBox[{\(1\/2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{\(-\[ImaginaryI]\), 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{"\[ImaginaryI]", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}], ")"}]}], ",", 
        RowBox[{\(1\/2\), " ", 
          RowBox[{"(", 
            RowBox[{\(-1\), "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}], ")"}]}]}], "}"}]], "Output",
  CellLabel->"Out[7]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[8]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[9]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
  "Total isospin operator is related to the total spin operator (see ",
  ButtonBox["spinss",
    ButtonStyle->"AddOnsLink"],
  ")."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(II = 
      pow[I\_x, 2] + pow[I\_y, 2] + pow[I\_z, 2]\), "\[IndentingNewLine]", 
    \(II == 3/4 - spinss[c[]] // ExpandAll\)}], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    RowBox[{\(3\/4\), " ", 
      RowBox[{"(", 
        RowBox[{"1", "-", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "-", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "-", 
          RowBox[{"2", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}], ")"}]}]], "Output",
  CellLabel->"Out[11]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["Verify some equalities", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(isospinplus[c[]] \[Equal] isospinx[c[]] + I\ isospiny[c[]] // 
      ExpandAll\), "\[IndentingNewLine]", 
    \(isospinminus[c[]] \[Equal] isospinx[c[]] - I\ isospiny[c[]] // 
      ExpandAll\)}], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[13]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["Isospin operators commute with the spin operators", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \({S\_x, S\_y, S\_z} = spinxyz[c[]]\), "\[IndentingNewLine]", 
    \(Outer[komutator, {S\_x, S\_y, S\_z}, {I\_x, I\_y, I\_z}]\)}], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(1\/2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}], ")"}]}], ",", 
        RowBox[{\(1\/2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\[ImaginaryI]", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "-", 
              RowBox[{"\[ImaginaryI]", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}], ")"}]}], ",", 
        RowBox[{\(1\/2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\<\"-\"\>", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}], ")"}]}]}], "}"}]], "Output",
  CellLabel->"Out[15]="],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{520, 1030},
WindowMargins->{{Automatic, 173}, {Automatic, 0}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "isospinxyz"->{
    Cell[1811, 55, 2026, 73, 158, "Usage",
      CellTags->{
      "isospinxyz", "isospinx", "isospiny", "isospinz", "isospinplus", 
        "isospinminus"}]},
  "isospinx"->{
    Cell[1811, 55, 2026, 73, 158, "Usage",
      CellTags->{
      "isospinxyz", "isospinx", "isospiny", "isospinz", "isospinplus", 
        "isospinminus"}]},
  "isospiny"->{
    Cell[1811, 55, 2026, 73, 158, "Usage",
      CellTags->{
      "isospinxyz", "isospinx", "isospiny", "isospinz", "isospinplus", 
        "isospinminus"}]},
  "isospinz"->{
    Cell[1811, 55, 2026, 73, 158, "Usage",
      CellTags->{
      "isospinxyz", "isospinx", "isospiny", "isospinz", "isospinplus", 
        "isospinminus"}]},
  "isospinplus"->{
    Cell[1811, 55, 2026, 73, 158, "Usage",
      CellTags->{
      "isospinxyz", "isospinx", "isospiny", "isospinz", "isospinplus", 
        "isospinminus"}]},
  "isospinminus"->{
    Cell[1811, 55, 2026, 73, 158, "Usage",
      CellTags->{
      "isospinxyz", "isospinx", "isospiny", "isospinz", "isospinplus", 
        "isospinminus"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"isospinxyz", 49541, 1269},
  {"isospinx", 49717, 1274},
  {"isospiny", 49893, 1279},
  {"isospinz", 50069, 1284},
  {"isospinplus", 50248, 1289},
  {"isospinminus", 50428, 1294}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 32, 0, 38, "ObjectName"],
Cell[1811, 55, 2026, 73, 158, "Usage",
  CellTags->{
  "isospinxyz", "isospinx", "isospiny", "isospinz", "isospinplus", 
    "isospinminus"}],
Cell[3840, 130, 247, 6, 40, "Notes"],
Cell[4090, 138, 116, 4, 24, "Notes"],
Cell[4209, 144, 254, 11, 24, "Notes"],

Cell[CellGroupData[{
Cell[4488, 159, 42, 0, 38, "ExampleSection"],
Cell[4533, 161, 117, 4, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[4675, 169, 139, 3, 42, "Input"],
Cell[4817, 174, 103, 2, 21, "Print"]
}, Open  ]],
Cell[4935, 179, 100, 4, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[5060, 187, 367, 7, 81, "Input"],
Cell[5430, 196, 11505, 261, 79, "Output"],
Cell[16938, 459, 62, 2, 25, "Output"],
Cell[17003, 463, 62, 2, 25, "Output"],
Cell[17068, 467, 62, 2, 25, "Output"]
}, Open  ]],
Cell[17145, 472, 100, 4, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[17270, 480, 367, 7, 81, "Input"],
Cell[17640, 489, 11355, 259, 79, "Output"],
Cell[28998, 750, 62, 2, 25, "Output"],
Cell[29063, 754, 62, 2, 25, "Output"],
Cell[29128, 758, 63, 2, 25, "Output"]
}, Open  ]],
Cell[29206, 763, 167, 5, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[29398, 772, 184, 4, 43, "Input"],
Cell[29585, 778, 6880, 169, 42, "Output"],
Cell[36468, 949, 63, 2, 25, "Output"]
}, Open  ]],
Cell[36546, 954, 45, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[36616, 958, 251, 5, 74, "Input"],
Cell[36870, 965, 63, 2, 25, "Output"],
Cell[36936, 969, 63, 2, 25, "Output"]
}, Open  ]],
Cell[37014, 974, 72, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[37111, 978, 183, 3, 45, "Input"],
Cell[37297, 983, 11468, 260, 79, "Output"],
Cell[48768, 1245, 92, 2, 25, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

