(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18532,        556]*)
(*NotebookOutlinePosition[     19222,        580]*)
(*  CellTagsIndexPosition[     19178,        576]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["scalarproductop", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["scalarproductop[", "MR"],
  StyleBox["a", "TI"],
  StyleBox[", ", "MR"],
  StyleBox["b", "TI"],
  StyleBox["]", "MR"],
  " computes the vacuum expectation value of the product between operator \
expressions ",
  StyleBox["a", "IT"],
  " and ",
  StyleBox["b", "IT"],
  ". The expression on the left, ",
  StyleBox["a", "IT"],
  ", is automatically conjugated."
}], "Usage"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["vevwick", "MR"],
  " is called to calculated the vacuum expectation value."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also:",
  ButtonBox["scalarproductvc",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["expvop",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["matrixrepresentationop",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["normop",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["decomposeop",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["orthogop",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell[TextData[{
  "Load sneg and let ",
  StyleBox["c", "TI"],
  " and ",
  StyleBox["d", "IT"],
  " be fermionic operators."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(snegfermionoperators[c, d];\)\), "\[IndentingNewLine]", 
    \(\(ordering[d] = SEA;\)\), "\[IndentingNewLine]", 
    \(\(snegfreeindexes[i, j, k, l];\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell["Simple examples", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(scalarproductop[1, 1] \[Equal] 1\), "\[IndentingNewLine]", 
    \(scalarproductop[c[CR], c[CR]] \[Equal] 1\), "\[IndentingNewLine]", 
    \(scalarproductop[c[CR, UP], c[CR, UP]] \[Equal] 
      1\), "\[IndentingNewLine]", 
    \(scalarproductop[c[CR, DO], c[CR, DO]] \[Equal] 
      1\), "\[IndentingNewLine]", 
    \(scalarproductop[c[CR, i, UP], c[CR, i, UP]] \[Equal] 1\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[5]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[6]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[7]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[8]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["The sign depends on the order of the operators", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(scalarproductop[nc[c[CR, UP], c[CR, DO]], 
        nc[c[CR, UP], c[CR, DO]]] \[Equal] 1\), "\[IndentingNewLine]", 
    \(scalarproductop[nc[c[CR, UP], c[CR, DO]], 
        nc[c[CR, DO], c[CR, UP]]] \[Equal] \(-1\)\)}], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[10]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["Generic indexes can be used", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(scalarproductop[nc[c[CR, i, UP], c[CR, j, DO]], 
      nc[c[CR, k, UP], c[CR, l, DO]]]\), "\[IndentingNewLine]", 
    \(scalarproductop[nc[c[CR, i, UP], c[CR, j, DO]], 
      nc[c[CR, k, DO], c[CR, l, UP]]]\), "\[IndentingNewLine]", 
    \(scalarproductop[nc[c[CR, i, UP], c[CR, j, UP]], 
      nc[c[CR, k, UP], c[CR, l, UP]]]\)}], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(i  k\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(j  l\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]], "Output",
  CellLabel->"Out[12]="],

Cell[BoxData[
    RowBox[{
      RowBox[{"-", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(i  l\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(j  k\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]], "Output",
  CellLabel->"Out[13]="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"-", 
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(i  l\)],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(j  k\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(i  k\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(j  l\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["\<\
The vacuum expectation value depends on the type of the \
vacuum.\
\>", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(scalarproductop[d[CR, k, UP], d[CR, k, UP]]\), "\[IndentingNewLine]", 
    \(scalarproductop[d[CR, k, UP], d[CR, l, UP]] // 
      Simplify\), "\[IndentingNewLine]", 
    \(scalarproductop[nc[d[CR, i, UP], d[CR, j, UP]], 
        nc[d[CR, k, UP], d[CR, l, UP]]] // Simplify\)}], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    TagBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"\[Colon]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)], 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"k", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {k, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          RowBox[{"If", "[", 
            RowBox[{\(k < 0\), ",", "0", ",", 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"k", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {k, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "]"}]}], 
        TagBox[
          StyleBox["\<\"\[Colon]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)]}],
      DisplayForm]], "Output",
  CellLabel->"Out[15]="],

Cell[BoxData[
    TagBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"\[Colon]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)], 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["d", 
                  RowBox[{"k", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ d, 
                  RowBox[ {k, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          RowBox[{"If", "[", 
            RowBox[{\(l < 0\), ",", "0", ",", 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      RowBox[{"l", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {l, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "]"}]}], 
        TagBox[
          StyleBox["\<\"\[Colon]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)]}],
      DisplayForm]], "Output",
  CellLabel->"Out[16]="],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Colon]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"i", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {i, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    RowBox[{"j", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {j, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            RowBox[{"If", "[", 
              RowBox[{\(l < 0\), ",", "0", ",", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"k", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {k, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"l", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {l, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}], "]"}]}], 
          TagBox[
            StyleBox["\<\"\[Colon]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)]}],
        DisplayForm]}]], "Output",
  CellLabel->"Out[17]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 194}, {49, Automatic}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 38, "ObjectName"],
Cell[1816, 55, 428, 15, 64, "Usage"],
Cell[2247, 72, 143, 4, 24, "Notes"],
Cell[2393, 78, 466, 20, 40, "Notes"],

Cell[CellGroupData[{
Cell[2884, 102, 42, 0, 38, "ExampleSection"],
Cell[2929, 104, 144, 6, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3098, 114, 264, 5, 74, "Input"],
Cell[3365, 121, 103, 2, 21, "Print"]
}, Open  ]],
Cell[3483, 126, 38, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3546, 130, 431, 8, 90, "Input"],
Cell[3980, 140, 62, 2, 25, "Output"],
Cell[4045, 144, 62, 2, 25, "Output"],
Cell[4110, 148, 62, 2, 25, "Output"],
Cell[4175, 152, 62, 2, 25, "Output"],
Cell[4240, 156, 62, 2, 25, "Output"]
}, Open  ]],
Cell[4317, 161, 69, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[4411, 165, 273, 5, 74, "Input"],
Cell[4687, 172, 63, 2, 25, "Output"],
Cell[4753, 176, 63, 2, 25, "Output"]
}, Open  ]],
Cell[4831, 181, 50, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[4906, 185, 386, 7, 106, "Input"],
Cell[5295, 194, 876, 26, 32, "Output"],
Cell[6174, 222, 922, 27, 32, "Output"],
Cell[7099, 251, 1872, 53, 32, "Output"]
}, Open  ]],
Cell[8986, 307, 96, 3, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[9107, 314, 333, 6, 74, "Input"],
Cell[9443, 322, 2309, 60, 33, "Output"],
Cell[11755, 384, 2309, 60, 33, "Output"],
Cell[14067, 446, 4425, 105, 36, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

